// -*- c++ -*-
//------------------------------------------------------------------------------
// $Id: DeckList.cpp,v 1.5 2004/06/05 04:06:54 vlg Exp $
//------------------------------------------------------------------------------
//                            DeckList.cpp
//------------------------------------------------------------------------------
//  Copyright (c) 2004 by Vladislav Grinchenko 
//
//  This program is free software; you can redistribute it and/or 
//  modify it under the terms of the GNU General Public License   
//  as published by the Free Software Foundation; either version  
//  2 of the License, or (at your option) any later version.      
//------------------------------------------------------------------------------
//
// Date   : Mar  1 2004
//
//------------------------------------------------------------------------------

#include "Granule-main.h"
#include "DeckList.h"
#include "Deck.h"
#include "DeckManager.h"
#include "TopMenuBar.h"
#include "Granule.h"
#include "MainWindow.h"

//------------------------------------------------------------------------------
// Static functions
//
string
DeckList::
get_bare_name (const string& fname_)
{
    string tmp (fname_);
	string::size_type idx = tmp.rfind ('/');
	if (idx != string::npos) {
		tmp.replace (0, idx+1, "");
	}
	idx = tmp.rfind ('.');
	if (idx != string::npos) {
		tmp.replace (idx, tmp.size (), "");
	}
	return tmp;
}

//------------------------------------------------------------------------------
// Data members
//
DeckList::
DeckList () : m_selected_deck (NULL)
{
	trace_with_mask("DeckList::DeckList", GUITRACE);	

	set_shadow_type (Gtk::SHADOW_ETCHED_OUT);
	set_policy (Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);

	m_list_store_ref = Gtk::ListStore::create (m_columns);
	m_tree_view.set_model (m_list_store_ref);
	m_tree_view.set_rules_hint ();

	int cnt = m_tree_view.append_column ("Decks", m_columns.m_name);
	Gtk::TreeViewColumn* column = m_tree_view.get_column (cnt - 1);
	column->set_sizing (Gtk::TREE_VIEW_COLUMN_FIXED);
	column->set_fixed_width (140);
	column->set_resizable ();

	m_tree_sel_ref = m_tree_view.get_selection ();
	m_tree_sel_ref->set_mode (Gtk::SELECTION_SINGLE);
	m_tree_sel_ref->signal_changed ().connect (
		SigC::slot (*this, &DeckList::on_name_selected));

	add (m_tree_view);
}

void
DeckList::
push_back (Deck* deck_)
{
	trace_with_mask("DeckList::push_back(Deck)", GUITRACE);

	Gtk::TreeModel::iterator iter = m_list_store_ref->append ();
	Gtk::TreeModel::Row row = *iter;
	Glib::ustring fname = Glib::ustring (row [m_columns.m_name]);

	row [m_columns.m_name] = get_bare_name (deck_->get_name ());
	row [m_columns.m_deck_ref] = deck_;
}

string 
DeckList::
get_name (iterator iter_) const
{
	Gtk::TreeModel::Row row = *iter_;
	return row [m_columns.m_name];
}

Deck*
DeckList::
get_deck (iterator iter_)
{
	Gtk::TreeModel::Row row = *iter_;
	Deck* deck = row [m_columns.m_deck_ref];
	return deck;
}

void
DeckList::
on_name_selected (void)
{
	trace_with_mask("DeckList::on_name_selected", GUITRACE);

	Gtk::TreeModel::iterator iter = m_tree_sel_ref->get_selected ();
	if (iter) {
		Gtk::TreeModel::Path path = m_list_store_ref->get_path (iter);
		Gtk::TreeModel::Row row = *iter;
		m_selected_deck = row [m_columns.m_deck_ref];
		TOPMENUBAR->set_deck_sensitivity (true, size ());
	}
}

void
DeckList::
unselect ()
{
	trace_with_mask("DeckList::unselect", GUITRACE);

	Gtk::TreeModel::iterator iter = m_tree_sel_ref->get_selected ();
	if (iter) {
		m_tree_sel_ref->unselect (iter);
		m_selected_deck = NULL;
	}
	TOPMENUBAR->set_deck_sensitivity (false, size ());
}

void
DeckList::
refresh_selected_name ()
{
	trace_with_mask("DeckList::refresh_selected_name", GUITRACE);

	Gtk::TreeModel::iterator iter = m_tree_sel_ref->get_selected ();
	if (iter) {
		Gtk::TreeModel::Path path = m_list_store_ref->get_path (iter);
		Gtk::TreeModel::Row row = *iter;

		Deck* deck = row [m_columns.m_deck_ref];
		row [m_columns.m_name] = get_bare_name (deck->get_name ());
	}
}
		
